@@ -142,7 +142,7 @@ class Trainer():
         # call the post proc function, like Postproc.save_csv:
         callback(pred_val = pred_val, true_val = true_val, net_params_path = net_params_path, run_mode = run_mode)
 
-def run(run_mode, config_file):
+def run(run_mode, config_file, neuralnets = neuralnets):
     device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
     cfg = Yaml(config_file).load()
 
